local awful = require("awful")
local gears = require("gears")
local beautiful = require("beautiful")
-- {{{ Rules
-- Rules to apply to new clients (through the "manage" signal).
local dockapps = {}
local dockapp_size = 64
awful.rules.rules = {
    -- All clients will match this rule.
    { rule = { },
      properties = { border_width = beautiful.border_width,
                     border_color = beautiful.border_normal,
                     focus = awful.client.focus.filter,
                     raise = true,
                     keys = require("core.binds.clientkeys"),
                     buttons = require("core.binds.clientbuttons"),
                     screen = awful.screen.preferred,
                     placement = awful.placement.no_overlap+awful.placement.no_offscreen,
                     requests_no_titlebar = false
}
    },

    -- Floating clients.
    { rule_any = {
        instance = {
          "DTA",  -- Firefox addon DownThemAll.
          "copyq",  -- Includes session name in class.
          "pinentry",
        },
        class = {
          "Arandr",
          "Blueman-manager",
          "Gpick",
          "Kruler",
          "MessageWin",  -- kalarm.
          "Sxiv",
          "Tor Browser", -- Needs a fixed window size to avoid fingerprinting by screen size.
          "Wpa_gui",
          "veromix",
          "xtightvncviewer"},

        -- Note that the name property shown in xprop might be set slightly after creation of the client
        -- and the name shown there might not match defined rules here.
        name = {
          "Event Tester",  -- xev.
        },
        role = {
          "AlarmWindow",  -- Thunderbird's calendar.
          "ConfigManager",  -- Thunderbird's about:config.
          "pop-up",       -- e.g. Google Chrome's (detached) Developer Tools.
        }
      }, properties = { floating = true }},

    -- Add titlebars to normal clients and dialogs
    { rule_any = {type = { "normal", "dialog" }
      }, properties = { titlebars_enabled = true }
    },

    -- Rules for dockapps
    { rule_any = { name = {
        "wmMand",
        "wmwork",
        "wmmisc",
        "wmmon"
    } },
        properties = { 
            skip_taskbar = true,
            dockable = true,
            titlebars_enabled = false,
            sticky = true,
            below = true,
            placement = awful.placement.top_right+awful.placement.no_offscreen,
            callback = function(c)
                while (#dockapps > 0) and (not dockapps[#dockapps].valid) do
                    table.remove(dockapps,#dockapps)
                end
                if #dockapps > 0 then
                    awful.placement.next_to(c,{
                        geometry = dockapps[#dockapps],
                        preferred_positions = "bottom",
                        preferred_anchors = "middle"
                    })
                end
                c.width = dockapps_size
                c.height = dockapps_size
                table.insert(dockapps,c)
            end
        },
    },

    -- Set Firefox to always map on the tag named "2" on screen 1.
    -- { rule = { class = "Firefox" },
    --   properties = { screen = 1, tag = "2" } },
    { rule_any = { class = { "onboard", "Onboard" }},
        properties = { focusable = false,
        focus = false }
    }

}
-- }}}
